##  Scenarios for the AI Model Subtype
The AI model subtype of the IT component fact sheet is available by default in new workspaces created after October 29, 2025. If your workspace was created before this date, explore possible scenarios and actions to take.
Workspace Creation Date | Workspace Configuration | Result and Follow-Ups
---|---|---
Workspace created after October 29, 2025 | N/a | The AI model subtype of the IT component fact sheet is available by default. You don't need to take any additional actions.
Workspace created before October 29, 2025 | The [AI governance](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension?locale=en-US&state=PRODUCTION&version=CLOUD "Improve AI governance and adoption in your organization. Track and manage AI usage, evaluate risks, and assess AI potential.") extension to the meta model was activated after November 3, 2025. | The extension adds the AI model subtype of the IT component fact sheet. You don't need to take any additional actions.
The [AI governance](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension?locale=en-US&state=PRODUCTION&version=CLOUD "Improve AI governance and adoption in your organization. Track and manage AI usage, evaluate risks, and assess AI potential.") extension to the meta model was activated before November 3, 2025. | The fact sheet subtype added by the [AI governance](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension?locale=en-US&state=PRODUCTION&version=CLOUD "Improve AI governance and adoption in your organization. Track and manage AI usage, evaluate risks, and assess AI potential.") extension is named “LLM.“ You can transition from the LLM to the new AI model subtype. To learn how, see [Transitioning to the AI Model Fact Sheet Subtype](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD#loio275aaf847a441014af8a80b1657917b9__section_hh5_w1j_hhc).
The [AI governance](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension?locale=en-US&state=PRODUCTION&version=CLOUD "Improve AI governance and adoption in your organization. Track and manage AI usage, evaluate risks, and assess AI potential.") extension to the meta model is not activated, and no custom subtype LLM is configured for IT components. |  You can add the AI model subtype in one of the following ways:
  * Activate the [AI governance](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension?locale=en-US&state=PRODUCTION&version=CLOUD "Improve AI governance and adoption in your organization. Track and manage AI usage, evaluate risks, and assess AI potential.") extension to the meta model. This extension adds the AI model subtype and other entities to your workspaces.
  * Create a custom fact sheet subtype AI model for IT components. Use aiModel as the subtype key. To learn how to create custom subtypes, see [Creating Custom Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/fact-sheet-subtype-management?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a19c87a441014814897963b6dd6de__creating_custom_fact_sheet_subtypes).


A custom subtype LLM is configured for the IT component fact sheet. | You can transition from the LLM to the new AI model subtype. To learn how, see [Transitioning to the AI Model Fact Sheet Subtype](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD#loio275aaf847a441014af8a80b1657917b9__section_hh5_w1j_hhc).


